"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.convertHttpContentEncodingToCompressionAlgorithm = exports.decompressBuffer = exports.compressBuffer = void 0;
const zlib_1 = __importDefault(require("zlib"));
function compressBuffer(algorithm, buffer) {
    switch (algorithm) {
        case "none":
            return buffer;
        case "br":
            return zlib_1.default.brotliCompressSync(buffer);
        case "gzip":
            return zlib_1.default.gzipSync(buffer);
        default:
            throw new Error(`Unhandled compression algorithm value "${algorithm}"`);
    }
}
exports.compressBuffer = compressBuffer;
function decompressBuffer(algorithm, buffer) {
    switch (algorithm) {
        case "none":
            return buffer;
        case "br":
            return zlib_1.default.brotliDecompressSync(buffer);
        case "gzip":
            return zlib_1.default.gunzipSync(buffer);
        default:
            throw new Error(`Unhandled compression algorithm value "${algorithm}"`);
    }
}
exports.decompressBuffer = decompressBuffer;
function convertHttpContentEncodingToCompressionAlgorithm(contentEncoding) {
    switch (contentEncoding) {
        case "":
            return "none";
        case "br":
            return "br";
        case "gzip":
            return "gzip";
        default:
            throw new Error(`Unhandled content-encoding value "${contentEncoding}"`);
    }
}
exports.convertHttpContentEncodingToCompressionAlgorithm = convertHttpContentEncodingToCompressionAlgorithm;
