"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.decodeHttpBodyToString = exports.getHttpBodyDecoded = exports.getHttpContentType = exports.getHttpContentEncoding = exports.getHttpHeaderAsString = void 0;
const compression_1 = require("./compression");
function getHttpHeaderAsString(headers, headerName) {
    const rawValue = headers[headerName];
    if (rawValue === undefined) {
        return "";
    }
    else if (typeof rawValue === "string") {
        return rawValue;
    }
    else {
        return rawValue[0];
    }
}
exports.getHttpHeaderAsString = getHttpHeaderAsString;
function getHttpContentEncoding(r) {
    return getHttpHeaderAsString(r.headers, "content-encoding");
}
exports.getHttpContentEncoding = getHttpContentEncoding;
function getHttpContentType(r) {
    return (getHttpHeaderAsString(r.headers, "content-type") ||
        "application/octet-stream");
}
exports.getHttpContentType = getHttpContentType;
function getHttpBodyDecoded(r) {
    const contentEncoding = getHttpHeaderAsString(r.headers, "content-encoding");
    const compressionAlgorithm = (0, compression_1.convertHttpContentEncodingToCompressionAlgorithm)(contentEncoding);
    return (0, compression_1.decompressBuffer)(compressionAlgorithm, r.body);
}
exports.getHttpBodyDecoded = getHttpBodyDecoded;
function decodeHttpBodyToString(r, contentType) {
    const encoding = contentType.parameters.charset;
    return getHttpBodyDecoded(r).toString(encoding || "utf-8");
}
exports.decodeHttpBodyToString = decodeHttpBodyToString;
