"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.send = void 0;
const chalk_1 = __importDefault(require("chalk"));
const http_1 = __importDefault(require("http"));
const https_1 = __importDefault(require("https"));
const buffer_1 = require("./buffer");
/**
 * Sends a network request and returns the recorded tape.
 */
function send(request, options) {
    return __awaiter(this, void 0, void 0, function* () {
        try {
            const [scheme, hostnameWithPort] = request.host.split("://");
            const [hostname, port] = hostnameWithPort.split(":");
            const response = yield new Promise((resolve, reject) => {
                const requestOptions = {
                    hostname,
                    method: request.method,
                    path: request.path,
                    port,
                    headers: Object.assign(Object.assign({}, request.headers), { host: hostname }),
                    timeout: options.timeout,
                };
                const proxyRequest = scheme === "http"
                    ? http_1.default.request(requestOptions, resolve)
                    : https_1.default.request(requestOptions, resolve);
                proxyRequest.on("error", reject);
                proxyRequest.write(request.body);
                proxyRequest.end();
            });
            const statusCode = response.statusCode || 200;
            const responseBody = yield new Promise((resolve) => {
                const chunks = [];
                response.on("data", (chunk) => {
                    chunks.push((0, buffer_1.ensureBuffer)(chunk));
                });
                response.on("end", () => resolve(Buffer.concat(chunks)));
            });
            return {
                request: {
                    method: request.method,
                    path: request.path,
                    headers: request.headers,
                    body: request.body,
                },
                response: {
                    status: {
                        code: statusCode,
                    },
                    headers: response.headers,
                    body: responseBody,
                },
            };
        }
        catch (e) {
            if (options.loggingEnabled) {
                const errorCode = e === null || e === void 0 ? void 0 : e.code;
                console.error(chalk_1.default.red(`Could not send request ${request.method} ${request.path} (error: ${errorCode || "unknown"})`));
            }
            throw e;
        }
    });
}
exports.send = send;
