"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const axios_1 = __importDefault(require("axios"));
const config_1 = require("./config");
const setup_1 = require("./setup");
const testserver_1 = require("./testserver");
describe("Match requests without passing exactRequestMatching arguement", () => {
    (0, setup_1.setupServers)({ mode: "replay", tapeDirName: "match-requests" });
    it("Picks the best match for a given request", () => __awaiter(void 0, void 0, void 0, function* () {
        // Start recording in tape "tape".
        yield axios_1.default.post(`${config_1.PROXAY_HOST}/__proxay/tape`, {
            tape: "tape",
            mode: "record",
        });
        // Pre-record a few requests and responses.
        yield axios_1.default.post(`${config_1.PROXAY_HOST}${testserver_1.JSON_IDENTITY_PATH}`, {
            field1: {
                key1: "a",
                key2: "b",
            },
            field2: "c",
            field3: 1,
        });
        yield axios_1.default.post(`${config_1.PROXAY_HOST}${testserver_1.JSON_IDENTITY_PATH}`, {
            field1: {
                key1: "a",
                key2: "b",
                key3: "c",
            },
            field2: "d",
            field3: 1,
        });
        yield axios_1.default.post(`${config_1.PROXAY_HOST}${testserver_1.JSON_IDENTITY_PATH}`, {
            field1: {
                key1: "z",
                key2: "a",
            },
            field2: "d",
            field3: 1,
        });
        // Switch to replay mode, same tape.
        yield axios_1.default.post(`${config_1.PROXAY_HOST}/__proxay/tape`, {
            tape: "tape",
            mode: "replay",
        });
        // Make sure the best possible match is picked each time.
        expect((yield axios_1.default.post(`${config_1.PROXAY_HOST}${testserver_1.JSON_IDENTITY_PATH}`, {
            field1: {
                key1: "z",
                key2: "a",
            },
            field2: "d",
            field3: 1,
        })).data).toEqual({
            field1: {
                key1: "z",
                key2: "a",
            },
            field2: "d",
            field3: 1,
            requestCount: 3,
        });
        expect((yield axios_1.default.post(`${config_1.PROXAY_HOST}${testserver_1.JSON_IDENTITY_PATH}`, {
            field1: {
                key1: "a",
                key2: "b",
            },
            field2: "d",
            field3: 1,
        })).data).toEqual({
            field1: {
                key1: "a",
                key2: "b",
            },
            field2: "c",
            field3: 1,
            requestCount: 1,
        });
    }));
});
describe("Match requests with exactRequestMatching true", () => {
    (0, setup_1.setupServers)({
        mode: "replay",
        tapeDirName: "match-requests",
        exactRequestMatching: true,
    });
    it("Picks the best match for a given request", () => __awaiter(void 0, void 0, void 0, function* () {
        // Start recording in tape "tape".
        yield axios_1.default.post(`${config_1.PROXAY_HOST}/__proxay/tape`, {
            tape: "tape",
            mode: "record",
        });
        // Pre-record a few requests and responses.
        yield axios_1.default.post(`${config_1.PROXAY_HOST}${testserver_1.JSON_IDENTITY_PATH}`, {
            field1: {
                key1: "a",
                key2: "b",
            },
            field2: "c",
            field3: 1,
        });
        yield axios_1.default.post(`${config_1.PROXAY_HOST}${testserver_1.JSON_IDENTITY_PATH}`, {
            field1: {
                key1: "a",
                key2: "b",
                key3: "c",
            },
            field2: "d",
            field3: 1,
        });
        yield axios_1.default.post(`${config_1.PROXAY_HOST}${testserver_1.JSON_IDENTITY_PATH}`, {
            field1: {
                key1: "z",
                key2: "a",
            },
            field2: "d",
            field3: 1,
        });
        // Switch to replay mode, same tape.
        yield axios_1.default.post(`${config_1.PROXAY_HOST}/__proxay/tape`, {
            tape: "tape",
            mode: "replay",
        });
        // Make sure the best possible match is picked each time.
        expect((yield axios_1.default.post(`${config_1.PROXAY_HOST}${testserver_1.JSON_IDENTITY_PATH}`, {
            field1: {
                key1: "z",
                key2: "a",
            },
            field2: "d",
            field3: 1,
        })).data).toEqual({
            field1: {
                key1: "z",
                key2: "a",
            },
            field2: "d",
            field3: 1,
            requestCount: 3,
        });
        expect((yield axios_1.default.post(`${config_1.PROXAY_HOST}${testserver_1.JSON_IDENTITY_PATH}`, {
            field1: {
                key1: "a",
                key2: "b",
            },
            field2: "c",
            field3: 1,
        })).data).toEqual({
            field1: {
                key1: "a",
                key2: "b",
            },
            field2: "c",
            field3: 1,
            requestCount: 1,
        });
    }));
});
