"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const axios_1 = __importDefault(require("axios"));
const config_1 = require("./config");
const setup_1 = require("./setup");
const testserver_1 = require("./testserver");
describe("Passthrough", () => {
    (0, setup_1.setupServers)({ mode: "passthrough" });
    test("response: simple text", () => __awaiter(void 0, void 0, void 0, function* () {
        const response = yield axios_1.default.get(`${config_1.PROXAY_HOST}${testserver_1.SIMPLE_TEXT_PATH}`);
        expect(response.data).toBe(testserver_1.SIMPLE_TEXT_RESPONSE);
    }));
    test("response: utf-8", () => __awaiter(void 0, void 0, void 0, function* () {
        const response = yield axios_1.default.get(`${config_1.PROXAY_HOST}${testserver_1.UTF8_PATH}`);
        expect(response.data).toBe(testserver_1.UTF8_RESPONSE);
    }));
    test("response: binary", () => __awaiter(void 0, void 0, void 0, function* () {
        const response = yield axios_1.default.get(`${config_1.PROXAY_HOST}${testserver_1.BINARY_PATH}`, {
            responseType: "arraybuffer",
        });
        expect(response.data).toEqual(testserver_1.BINARY_RESPONSE);
    }));
    test("can pick any tape", () => __awaiter(void 0, void 0, void 0, function* () {
        yield axios_1.default.post(`${config_1.PROXAY_HOST}/__proxay/tape`, {
            tape: "new-tape",
        });
    }));
});
describe("Passthrough with grpc-web+json unframing with explicit whitelisted hostname", () => {
    (0, setup_1.setupServers)({
        mode: "passthrough",
        unframeGrpcWebJsonRequestsHostnames: [`localhost:${config_1.TEST_SERVER_PORT}`],
    });
    test("response: simple text", () => __awaiter(void 0, void 0, void 0, function* () {
        const response = yield axios_1.default.get(`${config_1.PROXAY_HOST}${testserver_1.SIMPLE_TEXT_PATH}`);
        expect(response.data).toBe(testserver_1.SIMPLE_TEXT_RESPONSE);
    }));
    test("response: utf-8", () => __awaiter(void 0, void 0, void 0, function* () {
        const response = yield axios_1.default.get(`${config_1.PROXAY_HOST}${testserver_1.UTF8_PATH}`);
        expect(response.data).toBe(testserver_1.UTF8_RESPONSE);
    }));
    test("response: binary", () => __awaiter(void 0, void 0, void 0, function* () {
        const response = yield axios_1.default.get(`${config_1.PROXAY_HOST}${testserver_1.BINARY_PATH}`, {
            responseType: "arraybuffer",
        });
        expect(response.data).toEqual(testserver_1.BINARY_RESPONSE);
    }));
    test("can pick any tape", () => __awaiter(void 0, void 0, void 0, function* () {
        yield axios_1.default.post(`${config_1.PROXAY_HOST}/__proxay/tape`, {
            tape: "new-tape",
        });
    }));
    test("unframes a grpc-web+json request", () => __awaiter(void 0, void 0, void 0, function* () {
        const requestBody = Buffer.from([
            0, 0, 0, 0, 31, 123, 34, 101, 109, 97, 105, 108, 34, 58, 34, 102, 111,
            111, 46, 98, 97, 114, 64, 101, 120, 97, 109, 112, 108, 101, 46, 99, 111,
            109, 34, 125,
        ]);
        const response = yield axios_1.default.post(`${config_1.PROXAY_HOST}${testserver_1.GRPC_WEB_JSON_PATH}`, requestBody, {
            headers: {
                "content-type": "application/grpc-web+json",
                host: `localhost:${config_1.TEST_SERVER_PORT}`,
            },
        });
        expect(response.headers["content-type"]).toBe("application/json; charset=utf-8");
        expect(response.data).toEqual({ email: "foo.bar@example.com" });
    }));
});
describe("Passthrough with grpc-web+json unframing with wildcard whitelisted hostname", () => {
    (0, setup_1.setupServers)({
        mode: "passthrough",
        unframeGrpcWebJsonRequestsHostnames: ["*"],
    });
    test("response: simple text", () => __awaiter(void 0, void 0, void 0, function* () {
        const response = yield axios_1.default.get(`${config_1.PROXAY_HOST}${testserver_1.SIMPLE_TEXT_PATH}`);
        expect(response.data).toBe(testserver_1.SIMPLE_TEXT_RESPONSE);
    }));
    test("response: utf-8", () => __awaiter(void 0, void 0, void 0, function* () {
        const response = yield axios_1.default.get(`${config_1.PROXAY_HOST}${testserver_1.UTF8_PATH}`);
        expect(response.data).toBe(testserver_1.UTF8_RESPONSE);
    }));
    test("response: binary", () => __awaiter(void 0, void 0, void 0, function* () {
        const response = yield axios_1.default.get(`${config_1.PROXAY_HOST}${testserver_1.BINARY_PATH}`, {
            responseType: "arraybuffer",
        });
        expect(response.data).toEqual(testserver_1.BINARY_RESPONSE);
    }));
    test("can pick any tape", () => __awaiter(void 0, void 0, void 0, function* () {
        yield axios_1.default.post(`${config_1.PROXAY_HOST}/__proxay/tape`, {
            tape: "new-tape",
        });
    }));
    test("unframes a grpc-web+json request", () => __awaiter(void 0, void 0, void 0, function* () {
        const requestBody = Buffer.from([
            0, 0, 0, 0, 31, 123, 34, 101, 109, 97, 105, 108, 34, 58, 34, 102, 111,
            111, 46, 98, 97, 114, 64, 101, 120, 97, 109, 112, 108, 101, 46, 99, 111,
            109, 34, 125,
        ]);
        const response = yield axios_1.default.post(`${config_1.PROXAY_HOST}${testserver_1.GRPC_WEB_JSON_PATH}`, requestBody, {
            headers: {
                "content-type": "application/grpc-web+json",
                host: `localhost:${config_1.TEST_SERVER_PORT}`,
            },
        });
        expect(response.headers["content-type"]).toBe("application/json; charset=utf-8");
        expect(response.data).toEqual({ email: "foo.bar@example.com" });
    }));
});
