"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const axios_1 = __importDefault(require("axios"));
const config_1 = require("./config");
const setup_1 = require("./setup");
const testserver_1 = require("./testserver");
describe("Replay", () => {
    (0, setup_1.setupServers)({ mode: "replay" });
    test("response: simple text", () => __awaiter(void 0, void 0, void 0, function* () {
        const response = yield axios_1.default.get(`${config_1.PROXAY_HOST}${testserver_1.SIMPLE_TEXT_PATH}`);
        expect(response.data).toBe(testserver_1.SIMPLE_TEXT_RESPONSE);
    }));
    test("response: utf-8", () => __awaiter(void 0, void 0, void 0, function* () {
        const response = yield axios_1.default.get(`${config_1.PROXAY_HOST}${testserver_1.UTF8_PATH}`);
        expect(response.data).toBe(testserver_1.UTF8_RESPONSE);
    }));
    test("response: binary", () => __awaiter(void 0, void 0, void 0, function* () {
        const response = yield axios_1.default.get(`${config_1.PROXAY_HOST}${testserver_1.BINARY_PATH}`, {
            responseType: "arraybuffer",
        });
        expect(response.data).toEqual(testserver_1.BINARY_RESPONSE);
    }));
    test("can pick an existing tape", () => __awaiter(void 0, void 0, void 0, function* () {
        yield axios_1.default.post(`${config_1.PROXAY_HOST}/__proxay/tape`, {
            tape: "existing-tape",
        });
    }));
    test("cannot pick a tape that does not exist", () => __awaiter(void 0, void 0, void 0, function* () {
        yield expect(axios_1.default.post(`${config_1.PROXAY_HOST}/__proxay/tape`, {
            tape: "does-not-exist-tape",
        })).rejects.toEqual(new Error("Request failed with status code 404"));
    }));
});
