"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.setupServers = void 0;
const path_1 = __importDefault(require("path"));
const rimraf_1 = require("rimraf");
const server_1 = require("../server");
const config_1 = require("./config");
const testserver_1 = require("./testserver");
function setupServers({ mode, tapeDirName = mode, defaultTapeName = "default", unframeGrpcWebJsonRequestsHostnames, exactRequestMatching, }) {
    const tapeDir = path_1.default.join(__dirname, "tapes", tapeDirName);
    const servers = { tapeDir };
    beforeEach(() => {
        if (mode !== "replay") {
            (0, rimraf_1.rimrafSync)(tapeDir);
        }
    });
    beforeAll(() => __awaiter(this, void 0, void 0, function* () {
        servers.backend = new testserver_1.TestServer();
        servers.proxy = new server_1.RecordReplayServer({
            initialMode: mode,
            tapeDir,
            defaultTapeName,
            host: config_1.TEST_SERVER_HOST,
            timeout: 100,
            enableLogging: true,
            unframeGrpcWebJsonRequestsHostnames,
            exactRequestMatching,
        });
        yield Promise.all([
            servers.proxy.start(config_1.PROXAY_PORT),
            servers.backend.start(config_1.TEST_SERVER_PORT),
        ]);
    }));
    afterAll(() => __awaiter(this, void 0, void 0, function* () {
        yield Promise.all([servers.backend.stop(), servers.proxy.stop()]);
    }));
    return servers;
}
exports.setupServers = setupServers;
