"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.TestServer = exports.GRPC_WEB_JSON_PATH = exports.BINARY_RESPONSE = exports.BINARY_PATH = exports.JSON_IDENTITY_PATH = exports.UTF8_RESPONSE = exports.UTF8_PATH = exports.SIMPLE_TEXT_RESPONSE = exports.SIMPLE_TEXT_PATH = void 0;
const express_1 = __importDefault(require("express"));
exports.SIMPLE_TEXT_PATH = "/simpletext";
exports.SIMPLE_TEXT_RESPONSE = "Plain text!";
exports.UTF8_PATH = "/utf8";
exports.UTF8_RESPONSE = "😊 Hello 💩";
exports.JSON_IDENTITY_PATH = "/json/identity";
exports.BINARY_PATH = "/binary";
exports.BINARY_RESPONSE = Buffer.from([
    // These are not valid UTF-8 characters, on purpose.
    12, 48, 249, 104, 255, 33, 203, 179,
]);
exports.GRPC_WEB_JSON_PATH = "/grpc-web-json";
/**
 * A test server used as a fake backend.
 */
class TestServer {
    constructor() {
        this.requestCount = 0;
        this.app = (0, express_1.default)();
        this.app.use(express_1.default.json());
        this.app.use(express_1.default.raw({ type: () => true }));
        this.app.use((_req, _res, next) => {
            this.requestCount += 1;
            next();
        });
        this.app.get(exports.SIMPLE_TEXT_PATH, (_req, res) => {
            res.send(exports.SIMPLE_TEXT_RESPONSE);
        });
        this.app.get(exports.UTF8_PATH, (_req, res) => {
            res.send(exports.UTF8_RESPONSE);
        });
        this.app.get(exports.BINARY_PATH, (_req, res) => {
            res.send(exports.BINARY_RESPONSE);
        });
        this.app.post(exports.GRPC_WEB_JSON_PATH, (req, res) => {
            res.setHeader("content-type", req.headers["content-type"]);
            res.send(req.body);
        });
        this.app.get(exports.JSON_IDENTITY_PATH, (req, res) => {
            res.json({ data: req.path, requestCount: this.requestCount });
        });
        this.app.post(exports.JSON_IDENTITY_PATH, (req, res) => {
            res.json(Object.assign(Object.assign({}, req.body), { requestCount: this.requestCount }));
        });
        this.app.get("/*", (req, res) => {
            res.send(req.path);
        });
    }
    /**
     * Starts the server.
     */
    start(port) {
        return __awaiter(this, void 0, void 0, function* () {
            yield new Promise((resolve) => (this.server = this.app.listen(port, resolve)));
        });
    }
    /**
     * Stops the server.
     */
    stop() {
        return __awaiter(this, void 0, void 0, function* () {
            yield new Promise((resolve, reject) => {
                if (!this.server) {
                    return reject();
                }
                this.server.close(resolve);
            });
        });
    }
}
exports.TestServer = TestServer;
